@@ -47,9 +47,13 @@ con_gorica_est <- function(object, constraints = NULL, VCOV = NULL,
   # deal with constraints
   if (!is.null(constraints)) {
     restr.OUT <- con_constraints(object, 
+                                 VCOV        = Sigma,
+                                 est         = b.unrestr,
                                  constraints = Amat, 
                                  bvec        = bvec, 
                                  meq         = meq, 
+                                 mix.weights = mix.weights,
+                                 se          = "none",
                                  debug       = debug)  
     # a list with useful information about the restriktions.}
     CON <- restr.OUT$CON
